import Vue from 'vue'
import Router from 'vue-router'

Vue.use(Router)

/* Layout */
import Layout from '@/layout'

// 用户模式
const USER_LEVEL = {
  USER_VISITOR: 'USER_VISITOR', // 游客模式
  USER_LOGIN: 'USER_LOGIN' // 登录模式
}

// 游客模式 路由集合
const USER_VISITOR_ROUTES = [
  {
    path: '/login',
    name: 'login',
    redirect: '/login/index',
    component: Layout,
    meta: {
      title: '登录',
      USER_LEVEL: USER_LEVEL.USER_VISITOR
    },
    children: [
      {
        path: '/login/index',
        name: 'loginIndex',
        meta: { showFooter: true, showHeader: false, title: '登录', USER_LEVEL: USER_LEVEL.USER_VISITOR },
        component: () => import('@/views/login/login')
      }
    ]
  },
  // {
  //   path: '/searchCenter',
  //   name: 'searchCenter',
  //   redirect: '/searchCenter/index',
  //   component: Layout,
  //   meta: { title: '搜索', USER_LEVEL: USER_LEVEL.USER_VISITOR },
  //   children: [
  //     {
  //       path: '/searchCenter/index',
  //       name: 'searchCenterIndex',
  //       meta: { title: '搜索', USER_LEVEL: USER_LEVEL.USER_VISITOR, showHeader: false },
  //       component: () => import('@/views/searchCenter/index')
  //     }
  //   ]
  // },
  {
    path: '/',
    redirect: '/homePage/index',
    name: 'index',
    component: Layout,
    meta: {
      title: '首页',
      USER_LEVEL: USER_LEVEL.USER_VISITOR
    },
    children: [
      {
        path: '/homePage/index',
        name: 'homePage',
        meta: {
          showFooter: true,
          title: '首页',
          USER_LEVEL: USER_LEVEL.USER_VISITOR,
          showHeader: false,
          animation: false
        },
        component: () => import('@/views/homePage/index')
      },
      {
        path: '/PolicyDirect/index',
        name: 'PolicyDirect',
        meta: { title: '政策直达', USER_LEVEL: USER_LEVEL.USER_VISITOR, showHeader: false, animation: false },
        component: () => import('@/views/PolicyDirect/index')
      },
      {
        path: '/PolicyDirect/policyRecommendationsDetails',
        name: 'policyRecommendationsDetails',
        meta: { title: '政策推荐详情', USER_LEVEL: USER_LEVEL.USER_LOGIN, showHeader: false, animation: false },
        component: () => import('@/views/PolicyDirect/components/policyRecommendationsDetails')
      },
      {
        path: '/PolicyDirect/components/policySearchDetails',
        name: 'PolicySearchDetails',
        meta: { title: '政策详情', USER_LEVEL: USER_LEVEL.USER_VISITOR, showHeader: false, animation: false },
        component: () => import('@/views/PolicyDirect/components/policySearchDetails')
      },
      {
        path: '/PolicyDirect/components/policyIllustrationDetails',
        name: 'PolicyIllustrationDetails',
        meta: { title: '政策图解详情', USER_LEVEL: USER_LEVEL.USER_VISITOR, showHeader: false, animation: false },
        component: () => import('@/views/PolicyDirect/components/policyIllustrationDetails')
      },
      {
        path: '/ServiceShare/index',
        name: 'ServiceShare',
        meta: { title: '服务共享', USER_LEVEL: USER_LEVEL.USER_VISITOR, showHeader: false, animation: false },
        component: () => import('@/views/ServiceShare/index')
      },
      {
        path: '/ServiceShare/details',
        name: 'ServiceShare',
        meta: { title: '服务共享详情', USER_LEVEL: USER_LEVEL.USER_VISITOR, showHeader: false, animation: false },
        component: () => import('@/views/ServiceShare/details')
      },
      {
        path: '/ServiceShare/productServiceDetail',
        name: 'ServiceShare',
        meta: { title: '产品服务详情', USER_LEVEL: USER_LEVEL.USER_VISITOR, showHeader: false, animation: false },
        component: () => import('@/views/ServiceShare/productServiceDetail')
      },
      {
        path: '/EnterpriseAppeal/index',
        name: 'EnterpriseAppeal',
        meta: { title: '企业诉求', USER_LEVEL: USER_LEVEL.USER_VISITOR, showHeader: false, animation: false },
        component: () => import('@/views/EnterpriseAppeal/index')
      },
      {
        path: '/enterprise-appeal/message/add',
        name: 'AppealMessageAdd',
        meta: { title: '企业诉求留言板', USER_LEVEL: USER_LEVEL.USER_LOGIN, showHeader: false, animation: false },
        component: () => import('@/views/EnterpriseAppeal/AppealMessageAdd')
      },
      {
        path: '/OneClickService/index',
        name: 'OneClickService',
        meta: { title: '一键办事', USER_LEVEL: USER_LEVEL.USER_VISITOR, showHeader: false, animation: false },
        component: () => import('@/views/OneClickService/index')
      },
      {
        path: '/activityInformation/index',
        name: 'activityInformation',
        meta: { title: '活动信息', USER_LEVEL: USER_LEVEL.USER_VISITOR, showHeader: false, animation: false },
        component: () => import('@/views/activityInformation/index')
      },
      {
        path: '/activityInformation/details',
        name: 'activityInformationDetails',
        meta: { title: '活动信息详情', USER_LEVEL: USER_LEVEL.USER_VISITOR, showHeader: false, animation: false },
        component: () => import('@/views/activityInformation/details')
      },
      {
        path: '/personalCenter/index',
        name: 'tool',
        meta: { title: '个人中心', USER_LEVEL: USER_LEVEL.USER_LOGIN, showHeader: false, animation: false },
        component: () => import('@/views/personalCenter/index')
      },
      {
        path: '/personalCenter/updateInfo',
        name: 'tool',
        meta: { title: '编辑个人信息', USER_LEVEL: USER_LEVEL.USER_LOGIN, showHeader: false, animation: false },
        component: () => import('@/views/personalCenter/updateInfo')
      },
      {
        path: '/personalCenter/components/AffiliatedEnterprisesUpdate',
        name: 'tool',
        meta: { title: '编辑企业信息', USER_LEVEL: USER_LEVEL.USER_LOGIN, showHeader: false, animation: false },
        component: () => import('@/views/personalCenter/components/AffiliatedEnterprisesUpdate')
      },
      {
        path: '/personalCenter/messageDetails',
        name: 'tool',
        meta: { title: '消息详情', USER_LEVEL: USER_LEVEL.USER_LOGIN, showHeader: false, animation: false },
        component: () => import('@/views/personalCenter/messageDetails')
      },
      {
        path: '/personalCenter/myAppealDetails',
        name: 'myAppealDetails',
        meta: { title: '我的诉求详情', USER_LEVEL: USER_LEVEL.USER_LOGIN, showHeader: false, animation: false },
        component: () => import('@/views/personalCenter/myAppealDetails')
      },
      {
        path: '/homePage/todayReport',
        name: 'todayReport',
        meta: { title: '今日申报', USER_LEVEL: USER_LEVEL.USER_VISITOR, showHeader: false, animation: false },
        component: () => import('@/views/homePage/todayReport')
      }
    ]
  }
]
// 其他路由集合
const OTHER_ROUTES = [
  { path: '/404', hidden: true, component: () => import('@/views/404'), meta: { USER_LEVEL: USER_LEVEL.USER_VISITOR }},
  { path: '*', redirect: '/404' }
]

export default USER_VISITOR_ROUTES.concat(OTHER_ROUTES)
